//! The base crate for writing guest programs to run on ableOS.
//!
//! ableOS is not a target known to rustc, and so we rely on a general `--cfg` switch
//! to control the use of ableOS target specific code when underlying the portable
//! abstractions defined in this crate.
//!
//! To target ableOS, set `cfg(ableOS)` and `--target=wasm32-unknown-unknown`.
//! ```text
//! RUSTFLAGS='--cfg=ableOS' cargo build --target=wasm32-unknown-unknown
//! ```
#![no_std]

#[macro_use]
pub mod logger;
pub mod driver;
pub mod process;
pub mod syscalls;
#[cfg(feature = "io")]
pub mod io;
#[cfg(feature = "rng")]
pub mod rand;

pub use core::*;
