#![deny(missing_docs)]
//! This module provides declarations for all host provided functions.

use crate::process::{signals::Signals, PID};

pub mod file_calls;
pub mod time_calls;

/// All system calls are defined here.
extern "C" {

    /// Send a signal to a process
    ///
    /// # Arguments
    ///
    /// * `pid` - The PID of the process to send the signal to
    /// * `signal` - The signal to send
    pub fn send_signal(pid: PID, signal: Signals) -> bool;

    /// A temporary function to test the syscall interface
    pub fn add(a: u32, b: u32) -> u32;

    // TODO: ascertain whether the ableOS host provides randomness good enough for CSPRNGs
    /// The ableOS host provides entropy usable for seeding PRNGs.
    pub fn get_random() -> u32;

    // This currently has very x86 specific semantics.
    /// Pops a byte from the key buffer.
    pub fn get_input() -> i32;
}
